@@ -1,20 +1,4 @@
-# -*- coding: utf-8 -*-
-#
-# Copyright (C) 2013-2017 Gauvain Pocentek <gauvain@pocentek.net>
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
+import enum
 from types import ModuleType
 from typing import (
     Any,
@@ -73,7 +57,7 @@ class HeadMixin(_RestManagerBase):
     @exc.on_http_error(exc.GitlabHeadError)
     def head(
         self, id: Optional[Union[str, int]] = None, **kwargs: Any
-    ) -> requests.structures.CaseInsensitiveDict:
+    ) -> "requests.structures.CaseInsensitiveDict[Any]":
         """Retrieve headers from an endpoint.
 
         Args:
@@ -321,6 +305,13 @@ class CreateMixin(_RestManagerBase):
         return self._obj_cls(self, server_data)
 
 
+@enum.unique
+class UpdateMethod(enum.IntEnum):
+    PUT = 1
+    POST = 2
+    PATCH = 3
+
+
 class UpdateMixin(_RestManagerBase):
     _computed_path: Optional[str]
     _from_parent_attrs: Dict[str, Any]
@@ -328,7 +319,7 @@ class UpdateMixin(_RestManagerBase):
     _parent: Optional[base.RESTObject]
     _parent_attrs: Dict[str, Any]
     _path: Optional[str]
-    _update_uses_post: bool = False
+    _update_method: UpdateMethod = UpdateMethod.PUT
     gitlab: gitlab.Gitlab
 
     def _get_update_method(
@@ -339,8 +330,11 @@ class UpdateMixin(_RestManagerBase):
         Returns:
             http_put (default) or http_post
         """
-        if self._update_uses_post:
+        if self._update_method is UpdateMethod.POST:
             http_method = self.gitlab.http_post
+        elif self._update_method is UpdateMethod.PATCH:
+            # only patch uses required kwargs, so our types are a bit misaligned
+            http_method = self.gitlab.http_patch  # type: ignore[assignment]
         else:
             http_method = self.gitlab.http_put
         return http_method
@@ -622,7 +616,7 @@ class DownloadMixin(_RestObjectBase):
     def download(
         self,
         streamed: bool = False,
-        action: Optional[Callable] = None,
+        action: Optional[Callable[[bytes], None]] = None,
         chunk_size: int = 1024,
         *,
         iterator: bool = False,
@@ -755,7 +749,10 @@ class TimeTrackingMixin(_RestObjectBase):
         # Use the existing time_stats attribute if it exist, otherwise make an
         # API call
         if "time_stats" in self.attributes:
-            return self.attributes["time_stats"]
+            time_stats = self.attributes["time_stats"]
+            if TYPE_CHECKING:
+                assert isinstance(time_stats, dict)
+            return time_stats
 
         path = f"{self.manager.path}/{self.encoded_id}/time_stats"
         result = self.manager.gitlab.http_get(path, **kwargs)
@@ -908,7 +905,7 @@ class PromoteMixin(_RestObjectBase):
     _module: ModuleType
     _parent_attrs: Dict[str, Any]
     _updated_attrs: Dict[str, Any]
-    _update_uses_post: bool = False
+    _update_method: UpdateMethod = UpdateMethod.PUT
     manager: base.RESTManager
 
     def _get_update_method(
@@ -919,7 +916,7 @@ class PromoteMixin(_RestObjectBase):
         Returns:
             http_put (default) or http_post
         """
-        if self._update_uses_post:
+        if self._update_method is UpdateMethod.POST:
             http_method = self.manager.gitlab.http_post
         else:
             http_method = self.manager.gitlab.http_put
