@@ -23,6 +23,7 @@ from gitlab.base import RESTManager, RESTObject
 from gitlab.mixins import (
     CreateMixin,
     CRUDMixin,
+    DeleteMixin,
     GetWithoutIdMixin,
     ListMixin,
     ObjectDeleteMixin,
@@ -58,6 +59,7 @@ from .integrations import ProjectIntegrationManager, ProjectServiceManager  # no
 from .invitations import ProjectInvitationManager  # noqa: F401
 from .issues import ProjectIssueManager  # noqa: F401
 from .iterations import ProjectIterationManager  # noqa: F401
+from .job_token_scope import ProjectJobTokenScopeManager  # noqa: F401
 from .jobs import ProjectJobManager  # noqa: F401
 from .labels import ProjectLabelManager  # noqa: F401
 from .members import ProjectMemberAllManager, ProjectMemberManager  # noqa: F401
@@ -190,6 +192,7 @@ class Project(RefreshMixin, SaveMixin, ObjectDeleteMixin, RepositoryMixin, RESTO
     issues_statistics: ProjectIssuesStatisticsManager
     iterations: ProjectIterationManager
     jobs: ProjectJobManager
+    job_token_scope: ProjectJobTokenScopeManager
     keys: ProjectKeyManager
     labels: ProjectLabelManager
     members: ProjectMemberManager
@@ -625,37 +628,6 @@ class Project(RefreshMixin, SaveMixin, ObjectDeleteMixin, RepositoryMixin, RESTO
             path, post_data={"namespace": to_namespace}, **kwargs
         )
 
-    @cli.register_custom_action("Project", ("to_namespace",))
-    def transfer_project(self, *args: Any, **kwargs: Any) -> None:
-        utils.warn(
-            message=(
-                "The project.transfer_project() method is deprecated and will be "
-                "removed in a future version. Use project.transfer() instead."
-            ),
-            category=DeprecationWarning,
-        )
-        return self.transfer(*args, **kwargs)
-
-    @cli.register_custom_action("Project", ("ref_name", "artifact_path", "job"))
-    @exc.on_http_error(exc.GitlabGetError)
-    def artifact(
-        self,
-        *args: Any,
-        **kwargs: Any,
-    ) -> Optional[bytes]:
-        utils.warn(
-            message=(
-                "The project.artifact() method is deprecated and will be "
-                "removed in a future version. Use project.artifacts.raw() instead."
-            ),
-            category=DeprecationWarning,
-        )
-        data = self.artifacts.raw(*args, **kwargs)
-        if TYPE_CHECKING:
-            assert data is not None
-            assert isinstance(data, bytes)
-        return data
-
 
 class ProjectManager(CRUDMixin, RESTManager):
     _path = "/projects"
@@ -1230,11 +1202,13 @@ class ProjectForkManager(CreateMixin, ListMixin, RESTManager):
         return cast(ProjectFork, CreateMixin.create(self, data, path=path, **kwargs))
 
 
-class ProjectRemoteMirror(SaveMixin, RESTObject):
+class ProjectRemoteMirror(ObjectDeleteMixin, SaveMixin, RESTObject):
     pass
 
 
-class ProjectRemoteMirrorManager(ListMixin, CreateMixin, UpdateMixin, RESTManager):
+class ProjectRemoteMirrorManager(
+    ListMixin, CreateMixin, UpdateMixin, DeleteMixin, RESTManager
+):
     _path = "/projects/{project_id}/remote_mirrors"
     _obj_cls = ProjectRemoteMirror
     _from_parent_attrs = {"project_id": "id"}
